
RELEASE_VERSION='0.0.468882291'
BUILD_DATE='Fri Feb 11 13:02:06 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-0jhgcz 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2082886732'
GIT_COMMIT_SHA='8b1fde9003f3735d92eb60dfe45d6b6bae64f7d6'
GIT_BRANCH='main'
